@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        XRC.pm
-## Purpose:     Wx::XRC ( pulls in all wxWindows XML Resources )
+## Name:        ext/xrc/lib/Wx/XRC.pm
+## Purpose:     Wx::XRC (pulls in all wxWidgets XML Resources)
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     27/ 7/2001
-## RCS-ID:      
-## Copyright:   (c) 2001-2002 Mattia Barbon
+## Created:     27/07/2001
+## RCS-ID:      $Id: XRC.pm,v 1.11 2004/02/29 14:30:40 mbarbon Exp $
+## Copyright:   (c) 2001-2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -19,6 +19,9 @@ use vars qw($VERSION);
 
 $VERSION = '0.01';
 
+Wx::load_dll( 'xml' );
+Wx::load_dll( 'html' );
+Wx::load_dll( 'adv' );
 Wx::load_dll( 'xrc' );
 Wx::wx_boot( 'Wx::XRC', $VERSION );
 
